<a id="mypy-boto3-kinesis"></a>

# mypy-boto3-kinesis

[![PyPI - mypy-boto3-kinesis](https://img.shields.io/pypi/v/mypy-boto3-kinesis.svg?color=blue)](https://pypi.org/project/mypy-boto3-kinesis)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-kinesis.svg?color=blue)](https://pypi.org/project/mypy-boto3-kinesis)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-kinesis?color=blue)](https://pypistats.org/packages/mypy-boto3-kinesis)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Kinesis 1.17.102](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kinesis.html#Kinesis)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.21.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-kinesis docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesis/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-kinesis](#mypy-boto3-kinesis)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Kinesis` service.

```bash
python -m pip install boto3-stubs[kinesis]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[kinesis]` in your environment:
  `python -m pip install 'boto3-stubs[kinesis]'`

Both type checking and auto-complete should work for `Kinesis` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[kinesis]` in your environment:
  `python -m pip install 'boto3-stubs[kinesis]'`

Both type checking and auto-complete should work for `Kinesis` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[kinesis]` in your environment:
  `python -m pip install 'boto3-stubs[kinesis]'`
- Run `mypy` as usual

Type checking should work for `Kinesis` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[kinesis]` in your environment:
  `python -m pip install 'boto3-stubs[kinesis]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Kinesis` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`KinesisClient` provides annotations for `boto3.client("kinesis")`.

```python
import boto3

from mypy_boto3_kinesis import KinesisClient

client: KinesisClient = boto3.client("kinesis")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: KinesisClient = session.client("kinesis")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_kinesis.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_kinesis import KinesisClient
from mypy_boto3_kinesis.paginator import (
    DescribeStreamPaginator,
    ListShardsPaginator,
    ListStreamConsumersPaginator,
    ListStreamsPaginator,
)

client: KinesisClient = boto3.client("kinesis")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_stream_paginator: DescribeStreamPaginator = client.get_paginator("describe_stream")
list_shards_paginator: ListShardsPaginator = client.get_paginator("list_shards")
list_stream_consumers_paginator: ListStreamConsumersPaginator = client.get_paginator("list_stream_consumers")
list_streams_paginator: ListStreamsPaginator = client.get_paginator("list_streams")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_kinesis.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_kinesis import KinesisClient
from mypy_boto3_kinesis.waiter import (
    StreamExistsWaiter,
    StreamNotExistsWaiter,
)

client: KinesisClient = boto3.client("kinesis")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
stream_exists_waiter: StreamExistsWaiter = client.get_waiter("stream_exists")
stream_not_exists_waiter: StreamNotExistsWaiter = client.get_waiter("stream_not_exists")
```

<a id="literals"></a>

### Literals

`mypy_boto3_kinesis.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_kinesis.literals import (
    ConsumerStatusType,
    DescribeStreamPaginatorName,
    EncryptionTypeType,
    ListShardsPaginatorName,
    ListStreamConsumersPaginatorName,
    ListStreamsPaginatorName,
    MetricsNameType,
    ScalingTypeType,
    ShardFilterTypeType,
    ShardIteratorTypeType,
    StreamExistsWaiterName,
    StreamNotExistsWaiterName,
    StreamStatusType,
)

def check_value(value: ConsumerStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_kinesis.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_kinesis.type_defs import (
    AddTagsToStreamInputRequestTypeDef,
    ChildShardTypeDef,
    ConsumerDescriptionTypeDef,
    ConsumerTypeDef,
    CreateStreamInputRequestTypeDef,
    DecreaseStreamRetentionPeriodInputRequestTypeDef,
    DeleteStreamInputRequestTypeDef,
    DeregisterStreamConsumerInputRequestTypeDef,
    DescribeLimitsOutputTypeDef,
    DescribeStreamConsumerInputRequestTypeDef,
    DescribeStreamConsumerOutputTypeDef,
    DescribeStreamInputRequestTypeDef,
    DescribeStreamOutputTypeDef,
    DescribeStreamSummaryInputRequestTypeDef,
    DescribeStreamSummaryOutputTypeDef,
    DisableEnhancedMonitoringInputRequestTypeDef,
    EnableEnhancedMonitoringInputRequestTypeDef,
    EnhancedMetricsTypeDef,
    EnhancedMonitoringOutputTypeDef,
    GetRecordsInputRequestTypeDef,
    GetRecordsOutputTypeDef,
    GetShardIteratorInputRequestTypeDef,
    GetShardIteratorOutputTypeDef,
    HashKeyRangeTypeDef,
    IncreaseStreamRetentionPeriodInputRequestTypeDef,
    InternalFailureExceptionTypeDef,
    KMSAccessDeniedExceptionTypeDef,
    KMSDisabledExceptionTypeDef,
    KMSInvalidStateExceptionTypeDef,
    KMSNotFoundExceptionTypeDef,
    KMSOptInRequiredTypeDef,
    KMSThrottlingExceptionTypeDef,
    ListShardsInputRequestTypeDef,
    ListShardsOutputTypeDef,
    ListStreamConsumersInputRequestTypeDef,
    ListStreamConsumersOutputTypeDef,
    ListStreamsInputRequestTypeDef,
    ListStreamsOutputTypeDef,
    ListTagsForStreamInputRequestTypeDef,
    ListTagsForStreamOutputTypeDef,
    MergeShardsInputRequestTypeDef,
    PaginatorConfigTypeDef,
    PutRecordInputRequestTypeDef,
    PutRecordOutputTypeDef,
    PutRecordsInputRequestTypeDef,
    PutRecordsOutputTypeDef,
    PutRecordsRequestEntryTypeDef,
    PutRecordsResultEntryTypeDef,
    RecordTypeDef,
    RegisterStreamConsumerInputRequestTypeDef,
    RegisterStreamConsumerOutputTypeDef,
    RemoveTagsFromStreamInputRequestTypeDef,
    ResourceInUseExceptionTypeDef,
    ResourceNotFoundExceptionTypeDef,
    ResponseMetadataTypeDef,
    SequenceNumberRangeTypeDef,
    ShardFilterTypeDef,
    ShardTypeDef,
    SplitShardInputRequestTypeDef,
    StartStreamEncryptionInputRequestTypeDef,
    StartingPositionTypeDef,
    StopStreamEncryptionInputRequestTypeDef,
    StreamDescriptionSummaryTypeDef,
    StreamDescriptionTypeDef,
    SubscribeToShardEventStreamTypeDef,
    SubscribeToShardEventTypeDef,
    SubscribeToShardInputRequestTypeDef,
    SubscribeToShardOutputTypeDef,
    TagTypeDef,
    UpdateShardCountInputRequestTypeDef,
    UpdateShardCountOutputTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AddTagsToStreamInputRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-kinesis` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-kinesis docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesis/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
